@@ -3,8 +3,9 @@ context("generatePDF")
   # initial values
 wd<-getwd()
 basepath<-wd
-testpath<-file.path(tempdir())
 
+testpath<-file.path(basepath,"temp")
+dir.create(testpath)
 
 
 test_that("generatePDF - correct behaviour, DATED=FALSE,CLEANUP=TRUE",{
@@ -277,4 +278,4 @@ test_that("generatePDF - errors - missing inputs",{
   expect_false(file.exists(file.path(testpath,"basic.toc")))
 })
 
-file.remove(testpath)
+#file.remove(testpath)
